package com.lantone.qc.trans.changx;

import com.google.common.collect.Lists;
import com.lantone.qc.pub.model.doc.DeathCaseDiscussDoc;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.comsis.ModelDocGenerate;
import com.lantone.qc.trans.comsis.Preproc;

import java.util.List;
import java.util.Map;

/**
 * @Description: 死亡病例讨论记录文档生成
 * @author: rengb
 * @time: 2020/3/17 13:22
 */
public class ChangxDeathCaseDiscussDocTrans extends ModelDocTrans {

    @Override
    public DeathCaseDiscussDoc extract(MedrecVo medrecVo) {
        String content = ((List<String>) medrecVo.getContent().get("content")).get(0);

        Map<String, String> pageData = Preproc.extract_doc_pub(false, medrecVo.getLabel(), content);
        pageData.put("病程记录内容",
                pageData.get("病程记录内容")
                        .replace(pageData.get("病程记录时间"), "")
                        .replace(pageData.get("病程记录名称"), "")
        );

        List<String> targetTitles = Lists.newArrayList();
        sourceTitles.forEach(sourceTitle -> {
            String targetTitle = "";
            for (int index = 0; index < sourceTitle.length(); index++) {
                if (index == sourceTitle.length() - 1) {
                    targetTitle += sourceTitle.substring(index, index + 1);
                } else {
                    targetTitle += sourceTitle.substring(index, index + 1) + "[\\s\\p{Zs}]*";
                }
            }
            targetTitles.add(targetTitle);
        });

        Map<String, String> sourceMap = Preproc.extract_doc_pub(false, targetTitles, content);
        sourceMap.put("记录时间", sourceMap.get("病程记录时间"));
        if (StringUtil.isBlank(sourceMap.get("参加讨论人员"))) {
            sourceMap.put("参加讨论人员", sourceMap.get("参加讨论人员(包括职称及姓名)"));
        }
        if (StringUtil.isBlank(sourceMap.get("讨论主持人"))) {
            sourceMap.put("讨论主持人", sourceMap.get("主持人"));
        }
        if (StringUtil.isBlank(sourceMap.get("死亡时间"))) {
            sourceMap.put("死亡时间", sourceMap.get("出院时间"));
        }
        if (StringUtil.isBlank(sourceMap.get("死亡原因"))) {
            sourceMap.put("死亡原因", sourceMap.get("结论"));
        }

        DeathCaseDiscussDoc deathCaseDiscussDoc = ModelDocGenerate.deathCaseDiscussDocGen(sourceMap);
        deathCaseDiscussDoc.setText(content);
        deathCaseDiscussDoc.setPageData((Map) pageData);

        return deathCaseDiscussDoc;
    }

    private List<String> sourceTitles = Lists.newArrayList(
            "病程记录时间",
            "病程记录名称",
            "病程记录内容",
            "记录时间",
            "记录医师",
            "入院时间",
            "死亡时间",
            "出院时间",
            "入院诊断",
            "死亡诊断",
            "讨论时间",
            "讨论地点",
            "参加讨论人员(包括职称及姓名)",
            "参加讨论人员",
            "主持人",
            "讨论主持人",
            "讨论内容",
            "死亡原因",
            "结论"
    );

}